% Script for graphics from the document "Matlab for Scilab Users"
%prepared by Gilberto Urroz, September 2004

echo on
%Example 1  Plot lists of numbers representing points in the plane
% Compute average temperature and
% plot the temperature data.
%
time = [0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, ...
3.5, 4.0, 4.5, 5.0];
temps = [105, 126, 119, 129, 132, 128, 131,...
      135, 136, 132, 137];
pause
average = mean(temps)
pause

plot (time, temps), title('Temperature Measurements'),
xlabel ('Time, minutes')
ylabel ('Temperature, degrees F'), grid
pause


%Example 2  Plot a function
% Plot a function y = f(x) = exp(-0.05*x)*cos(2.5*x-2)
%
x = 0:0.1:40;
y = exp(-0.05*x).*cos(2.5*x-2);
pause

plot (x,y), title('Plot of function exp(-0.05x)cos(2.5x-2)'),
xlabel ('x')
ylabel ('y= f(x)'), grid
pause

% Plot a function y = f(x) = exp(-0.05*x)*cos(2.5*x-2)using fplot
%
fplot('exp(-0.05*x)*cos(2.5*x-2)',[0 50]);
title('fPlot of function exp(-0.05x)cos(2.5x-2)'),
xlabel ('x')
ylabel ('y= f(x)'), grid
pause


%Example 3  Defining line styles, markers, and colors
% Plots with different line styles, markers, and colors
x = 0:0.5:40;
y = sin(0.5*x);
z = cos(0.5*x);
w = exp(-0.05*x);
plot(x,y,'b-d',x,z,'m-.^',x,w,'r--O'), xlabel ('x'),ylabel ('y= f(x)')
pause


%Example 4  Plot in polar coordinates
%A plot in polar coordinates
theta = 0:pi/50:2*pi;
r = 2.5.*(1+2*cos(theta));
polar(theta, r), title('Example of a polar plot')
pause


%Example 5 - Parametric plots
 t = [0:0.1:20];
 x = sin(2*t);
 y = cos(t/2);
 plot(x,y)
pause


%Example 6  Plotting complex numbers
 x = randn(10,1); %generates 10 random values of x
 y = randn(10,1); %generates 10 random values of y
 compass(x,y)
pause

 
 %Example 7 - Plotting with logarithmic scales
 x = 10:1:10000; y = log(x/2)+1;
 loglog(x,y)
pause

 semilogx(x,y)
pause

 semilogy(x,y)
pause


% Example 8  Plotting a curve in space using parametric equations
 t=[0:0.1:100];
 plot3(sin(t),cos(t),t.^4)
pause

 
 %Example 9  Plot of a function z = f(x,y)
 x = -10:0.25:10; %Generates values of x
 y = -5:0.1:5; %Generates values of y
pause

 [X,Y] = meshgrid(x,y); %Generate a grid of values in (x,y)
pause

 Z = sin(X).*cos(Y); %Calculate z = f(X,Y)
pause

 mesh(X,Y,Z) %Get a mesh plot
pause

 
 %With the same data (X,Y,Z), use the surf command to get:
 surf(X,Y,Z) %Get a surface plot
pause

 
 % Example 10  Variants of the mesh and surf command
 x = [-2:0.1:2];
 [X,Y] = meshgrid(x); % same as meshgrid(x,x)
 Z = sin(X).*cos(Y);
pause

 mesh(X,Y,Z) % figure 1 shows regular mesh plot
pause

 meshc(X,Y,Z) % figure 1 shows mesh with contours
pause

 meshz(X,Y,Z) % figure 1 shows mesh with solid cuts
pause

 waterfall(X,Y,Z) % figure 1 shows a 'waterfall-style' mesh
pause

 surfc(X,Y,Z) % figure 1 shows surface plot with contours
pause

 
 %Example 11  Contour and density plots
 x = -10:0.25:10;
 y = -5:0.1:5;
 [X,Y] = meshgrid(x,y);
 Z = sin(X).*cos(Y);
pause

 contour(X,Y,Z) %generate a contour plot
pause

 pcolor(X,Y,Z) %generate a color (density) plot
pause

 
 % Example 12  Combining contour and density plots
 % This script generates a combined contour-density plot
x = -10:0.5:10;
y = -5:0.25:5;
[X,Y] = meshgrid(x,y);
Z = sin(X).*cos(Y);
pause

pcolor(X,Y,Z) % generate color density plot (includes grid)
pause

shading interp % remove grid from the density plot
pause

hold on % retains current figure for more graphic output
contour(X,Y,Z,10,'k') % plot 10 contour lines in black ('k')
hold off % releases current figure
title('Example of contour-density plot combination')

% End of Script
