% Script for graphics with Matlab
% prepared by Gilberto E. Urroz, August 2004
echo on
% First, we present function 'plot' with an example:
x = [0:0.5:10]; y = sin(x)+2.5*sin(2*x)-1.2*sin(3*x);
plot(y)   % plots y vs. index in vector  -- see figure 1
pause

plot(x,y) % plots y vs. s -- see figure 1
pause

% Modifying the view vindow
axis([-2 13 -6 6]);   % [xmin xmax ymin ymax]
pause

% Use a third argument to modify line color:
% 'y' produces a yellow line      'm' produces a magenta color line
% 'c' produces a cyan color line  'r' produces a red line
% 'g' produces a green line       'b' produces a blue line
% 'w' produces a white line       'k' produces a black line
% Examples:

plot(x,y,'g')   % see figure 1
pause

plot(x,y,'r')   % see figure 1
pause

%You can also change the type of graph output by using:
% '.' Uses dots to plot points          'o' Uses circles to plot data points
% 't' Uses treefoils to plot points     '+' Uses crosses to plot data points
% '*' Uses asterisks to plot points     'f' Uses filled diamonds for points
% 'd' Uses blank diamonds for points    'v' Uses triangles for points
% '^' Uses circle and cross for points
% Examples:
plot(x,y,'o')
pause

plot(x,y,'+')
pause

% Types of lines available:
% '-' solid line '--' dashed line '-.' dashed-dot line
% Examples:
plot(x,y,'-')
pause

plot(x,y,'--') 
pause 

plot(x,y,'-.')
pause

% Combining specs:
plot(x,y,'m--')
pause

plot(x,y,'o-')
pause

plot(x,y,'k+-')
pause

plot(x,y,'c^') 
pause

plot(x,y,'rd-')
pause

% Function 'hold' allows to modify an existing plot, e.g.,
plot(x,y,'r-')   % plot red line
pause

hold             % hold current plot
pause

plot(x,y,'bo')   % plot same data with blue circles
pause

hold             % release plot
pause

% Similar procedure, but in a single line:
plot(x,y,'mv');hold;plot(x,y,'b-');hold
pause

% 'plot' and 'hold' used to plot two sets of data in the same set of axes:
x = [0:0.5:10]; y = exp(-0.05*x).*cos(5*x); z = sin(x)+sin(2*x);
plot(x,y,'m--')
hold
plot(x,z,'r-.')
hold
pause

% Add grid to data
plot(x,y); grid on
pause

% Remove grid if it is on:
grid off
pause

% Labels in x and y
xlabel('x data'); ylabel('y data');
pause

% Add a title
title('a first graph')
pause

% Logarithmic scales
x = [0.5 14.5 153.6 789.5 1456.0 6789.0 11345.2 89567.3];
y = [12.5 13.6 17.8 25.3 38.7 12.56 8.32 2.34];
plot(x,y)      % natural scale plot
pause

semilogx(x,y)  % logarithmic scale in x
pause

semilogy(x,y)  % logarithmic scale in y
pause

loglog(x,y)    % logarithmic scales in both x and y
pause

% Third argument allowed as in 'plot':
loglog(x,y,'+')
pause

semilogy(x,y,'r-.')
pause

% You can add title and labels
xlabel('x'); ylabel('y'); title('a semilog plot');
pause

% Plotting more than one data set with a single 'plot' call
x = [0:0.1:10]; y = sin(x); z = cos(x); w = y + z;
plot(x,y,x,z,x,w);
pause

% adding specs to 'plot':
plot(x,y,'+',x,z,'o',x,w,'x')
pause

% Examples with logarithmic scales
x = [1,10,100,1000,10000]; y = sqrt(x);
z = x.^(1/3); w = x.^(1/4);
semilogx(x,y,x,z,x,w)
pause

semilogy(y,x,z,x,w,x)
pause

loglog(x,y,x,z,x,w)
pause

% Using specs for logarithmic scale plots
semilogx(x,y,'r+',x,z,'b-.',x,w,'d')
pause

semilogy(y,x,'--',z,x,'-.',w,x,'-')
pause

loglog(x,y,'+',x,z,'o',x,w,'x')
pause

% Adding legends:
semilogx(x,y,x,z,x,w)
legend('pressure 1','pressure 2', 'pressure 3')
pause

% A position argumen can be added to 'label'.  Possible values are:
%    -1 = outside the axis box on the right
%     1 = Upper right-hand corner (default)
%     2 = Upper left-hand corner
%     3 = Lower left-hand corner
%     4 = Lower right-hand corner
% Note: Interactive placement with the mouse is available for options 1-4
% Examples:
x = [0:0.1:10]; y = sin(x); z = cos(x); w = y + z;
plot(x,y,'+-.',x,w,'x-');legend('sine function','cosine function',-1)
pause

plot(x,y,'+-.',x,w,'x-');legend('sine function','cosine function',1)
pause

plot(x,y,'+-.',x,w,'x-');legend('sine function','cosine function',2)
pause

plot(x,y,'+-.',x,w,'x-');legend('sine function','cosine function',3)
pause

plot(x,y,'+-.',x,w,'x-');legend('sine function','cosine function',4)
pause

% Creating, clearing, and deleting graphics windows
% Function 'figure' generates a new graphics figure, e.g.,
figure(3)
pause

plot(x,y)
pause

% To clear the figure use 'clf'
clf(3)
pause

% Plot a new graph
plot(x,z)
pause

% Delete the figure
delete(3)
pause

% 'figure' without an argument produces the next available figure
figure
pause


% Another exercise:
x = [0:1:10]; y = sin(x)+cos(x);
figure;plot(x,y)
pause

figure(5);plot(x,y)
pause

clf(5);plot(y,x)
pause

figure;plot(x,y)
pause

% Working with subplots
x = [0:0.1:10]; y = sin(x); z = cos(x); w = y + z;
subplot(2,2,1);plot(x,y,'r+-.');title('plot(2,2,1)');xlabel('x');ylabel('y');
pause
subplot(2,2,2);plot(x,z,'d');title('plot(2,2,2)');xlabel('x');ylabel('y');
pause
subplot(2,2,3);plot(x,w,'mv');title('plot(2,2,3)');xlabel('x');ylabel('y');
pause
subplot(2,2,4);plot(x,y,'-.');title('plot(2,2,4)');xlabel('x');ylabel('y');
pause

% Here is an example with 6 subplots:
x = [-10:0.1:10];y1=sin(x);y2=sin(2*x);y3=sin(3*x);y4=cos(x);y5=cos(2*x);y6=cos(3*x);
subplot(2,3,1);plot(x,y1,'r+');title('plot 1');xlabel('x1');ylabel('y1');
subplot(2,3,2);plot(x,y2,'g.');title('plot 2');xlabel('x2');ylabel('y2');
subplot(2,3,3);plot(x,y3,'bd');title('plot 3');xlabel('x3');ylabel('y3');
subplot(2,3,4);plot(x,y4,'cx');title('plot 4');xlabel('x4');ylabel('y4');
subplot(2,3,5);plot(x,y5,'ko');title('plot 5');xlabel('x5');ylabel('y5');
subplot(2,3,6);plot(x,y6,'-.');title('plot 6');xlabel('x6');ylabel('y6');
pause

% Plotting lines in 3 dimensions
f1 = inline('3.5*sin(t/2)')
pause

f2 = inline('3.5*cos(t/2)')
pause

f3 = inline('1.2*t')
pause

t = [0:0.1:20]; x = f1(t); y = f2(t); z = f3(t);
figure; plot3(x,y,z)
pause

clf; plot3(x,y,z,'+'); % using specs

% A second example:
f1 = inline('A*sin(t)','A','t')
pause

f2 = inline('A*cos(t)','A','t')
pause

f3 = inline('A*t','A','t')
pause

t=[0:0.1:40]; %Values of t
A=3;x1=f1(A,t);y1=f2(A,t);z1=f3(A,t); % (x,y,z) data for A = 3
A=2;x2=f1(A,t);y2=f2(A,t);z2=f3(A,t); % (x,y,z) data for A = 2
A=5;x3=f1(A,t);y3=f2(A,t);z3=f3(A,t); % (x,y,z) data for A = 1

% Different plots:
plot3(x1,y1,z1)
pause

plot3(x2,y2,z2)
pause

plot3(x3,y3,z3)
pause

% plotting one, two, or three helices
plot3(x1,y1,z1,'+')
pause

plot3(x1,y1,z1,'+',x2,y2,z2,'x')
pause

plot3(x1,y1,z1,'+',x2,y2,z2,'x',x3,y3,z3,'-')
pause

% Building matrices of coordinates:
X = [x1' x2' x3']; % Put together X matrix
Y = [y1' y2' y3']; % Put together Y matrix
Z = [z1' z2' z3']; % Put together Z matrix

% Plot the various curves
plot3(X,Y,Z)
pause

% Adding specs
plot3(X,Y,Z,'r')
pause

plot3(X,Y,Z,'-')
pause

plot3(X,Y,Z,'-.')
pause

% Changing the view point for a 3d graph
plot3(X,Y,Z,'-.');view([20,50])  % specifying angles of view line
pause

plot3(X,Y,Z,'-.');view([5,3,20]) % specifying coordinates of view point
pause

% Changing the domain of the plot
plot3(X,Y,Z); axis([-5 5 -5 5 -10 200])
pause

% Changing domain and view point
plot3(X,Y,Z,'-.');view([1,1,20]);axis([-5 5 -5 5 -10 200]);
pause

% Plot 3-d surfaces with 'mesh', 'surf', and 'waterfall'
x = [-5:0.5:5]; y = [-7.5:0.5:7.5]; % Grid of data
pause

fm = inline('x.*sin(y)+y.*sin(x)')
pause

[X Y] = meshgrid(x,y);  % Generate matrix for evaluating function
Z = fm(X,Y);            % Evaluate function in grid
pause

mesh(X,Y,Z)					% Plot mesh
pause

surf(X,Y,Z)			      % Plot surface
pause

waterfall(X,Y,Z)        % Plot waterfall
pause

% Parametric equations for a surface: x = x(u,v), y = y(u,v), z = z(u,v)
% fx, fy, fz define the functions x(u,v), y(u,v) and z(u,v):
fx = inline('sin(u).*cos(v)','u','v')
pause
fy = inline('cos(u).*sin(v)','u','v')
pause
fz = inline('u+v','u','v')
pause
u = [0:0.1:1]; v = [1:0.1:2];            % grid points in u,v
[U,V] = meshgrid(u,v);                   % mesh of grid points U,V
X = fx(U,V); Y = fy(U,V); Z = fz(U,V);   % matrices of coordinates
pause
mesh(X,Y,Z);				% mesh 3d graph
pause
surf(X,Y,Z);            % surface 3d graph
pause
waterfall(X,Y,Z);       % waterfall 3d graph
pause

% See 'Graphs2_Script.m' for more graphs examples
% End of script